@@ -1,5 +1,5 @@
 package Convert::IBM390;
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 #--- DUMMY ----------------------------------------------------------
 #
@@ -139,7 +139,8 @@ that the high nybble must always come first in the input.
 
 The maximum length of a packed field is 16 bytes; of a zoned field, 32
 bytes.  All other fields may have a maximum specifier (length or repeat
-count) of 32767.  These maxima are enforced.
+count) of 32767.  The maximum length of the output structure is 36KB.
+These maxima are enforced.
 
 =item B<unpackeb> TEMPLATE RECORD
 
@@ -226,6 +227,32 @@ C<Convert::IBM390::version>.
 
 =back
 
+=head1 A COBOL EXAMPLE
+
+Suppose you have a mainframe record described thus in Cobol:
+
+ 01  ACPDB-RECORD.
+     03  ACPDB-FIRST-DATE-TRANS.
+         05  ACPDB-FD-TRANS-CN   PIC XX.
+         05  ACPDB-FD-TRANS-YR   PIC XX.
+         05  ACPDB-FD-TRANS-MO   PIC XX.
+         05  ACPDB-FD-TRANS-DA   PIC XX.
+     03  ACPDB-LAST-DATE-TRANS.
+         05  ACPDB-LD-TRANS-CN   PIC XX.
+         05  ACPDB-LD-TRANS-YR   PIC XX.
+         05  ACPDB-LD-TRANS-MO   PIC XX.
+         05  ACPDB-LD-TRANS-DA   PIC XX.
+     03  ACPDB-TOTAL-ITEMS       PIC S9(9)       COMP.
+     03  ACPDB-TOTAL-NO-TRANS    PIC S9(5)       COMP-3.
+     03  ACPDB-TOTAL-DOLLARS-1   PIC S9(7)V99    COMP-3.
+     03  ACPDB-PREV-YR-DOLLARS   PIC S9(7)V99    COMP-3.
+     03  ACPDB-RETURNED-ITEMS    PIC S9(4)       COMP.
+     03  ACPDB-DOLL-CD-PREV-BASE PIC XX.
+
+You would unpack the record like this:
+
+  @fields = unpackeb('e8 e8 i p3.0 p5.2 p5.2 s e2', $inrecord)
+
 =head1 REFERENCES
 
 IBM ESA/390 Principles of Operation, SA22-7201.
@@ -243,5 +270,6 @@ None, of course.  What do you think this is -- Unix?
 Convert::IBM390 was written by Geoffrey Rommel
 E<lt>GROMMEL@cpan.orgE<gt>
 in January 1999.
+Thanks to Barry Roomberg for the Cobol example.
 
 =cut
